# CliMetLab

[![PyPI version fury.io](https://badge.fury.io/py/climetlab.svg)](https://pypi.python.org/pypi/climetlab/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/climetlab.svg)](https://pypi.python.org/pypi/climetlab/)
[![Build](https://github.com/ecmwf/climetlab/actions/workflows/long-test.yml/badge.svg)](https://github.com/ecmwf/climetlab/actions/workflows/long-test.yml)

**CliMetLab** is a Python package aiming at simplifying access to climate and meteorological datasets, allowing users to focus on science instead of
technical issues such as data access and data formats. It is mostly intended to be used in Jupyter notebooks, and be interoperable with all popular
data analytic packages, such as Numpy, Pandas, Xarray, SciPy, Matplotlib, etc. as well as machine learning frameworks, such as Tensorflow, Keras or PyTorch.

The documentation can be found at <https://climetlab.readthedocs.io/>.

### Plugins

See https://climetlab.readthedocs.io/en/latest/guide/pluginlist.html.

### License
[Apache License 2.0](LICENSE) In applying this licence, ECMWF does not waive the privileges and immunities 
granted to it by virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.

 
